/*
		       Endeavour Process Execution

	To run a program specified by the MIME Type of a given disk object
	path or name.
 */

#ifndef EDVOPEN_H
#define EDVOPEN_H

#include <glib.h>
#include "edvtypes.h"
#include "edvmimetypes.h"
#include "endeavour.h"


extern gint EDVOpenObjectPath(
	edv_core_struct *core_ptr, const gchar *path,
	const gchar *command_name,
	GtkWidget *toplevel, gboolean verbose,
	gchar **stdout_path_rtn, gchar **stderr_path_rtn
);

extern gint EDVOpenWithObjectPath(
	edv_core_struct *core_ptr, const gchar *path,
	const gchar *command_name,
	GtkWidget *toplevel, gboolean verbose,
	gchar **stdout_path_rtn, gchar **stderr_path_rtn
);


#endif	/* EDVOPEN_H */
